@@ -80,6 +80,12 @@ class Servico:
         json = self.status().json()
         return False if not json else "E" == json[0].get('status', False)
 
+    def executado(self):
+        json = Controle.get().json()
+        for controle in json:
+            if controle['_id_servico'] == self.id:
+                return controle['executado']
+
 
 class Controle:
 
